package ocaml-canvas

  1. Overview
  2. Docs

Module OcamlCanvas.V1Source

The OCaml-Canvas module is versioned. This is version 1. It is guaranteed that this interface will always remain compatible with existing programs, provided that the modules defined here ARE NEVER included in other modules nor opened globally. Local opens should be performed very carefully, as new identifiers may be introduced in modules and thus shadow any identifier defined before the open directive. An effort will be made to avoid introducing new identifiers that are of length 3 of less, or starting with a single character followed by an underscore. Hence such identifiers should be safe to use without risking to be shadowed.

Sourcemodule Exception : sig ... end

OCaml-Canvas' exceptions

Sourcemodule Const : sig ... end

Some useful mathematical constants

Sourcemodule Vector : sig ... end

Vector manipulation functions

Sourcemodule Transform : sig ... end

Transform manipulation functions

Sourcemodule Point : sig ... end

Point manipulation functions

Sourcemodule Color : sig ... end

Color description and manipulation functions

Sourcemodule Font : sig ... end

Font description

Sourcemodule ImageData : sig ... end

Image data manipulation functions

Sourcemodule Gradient : sig ... end

Gradient manipulation functions

Sourcemodule Pattern : sig ... end

Pattern manipulation functions

Sourcemodule Path : sig ... end

Path manipulation functions

Sourcemodule Join : sig ... end
Sourcemodule Cap : sig ... end
Sourcemodule Style : sig ... end
Sourcemodule CompositeOp : sig ... end
Sourcemodule Canvas : sig ... end

Canvas manipulation functions

Sourcemodule Event : sig ... end

Event descriptions

Sourcemodule Backend : sig ... end

Initialization and event loop control