Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
V1.GradientSourceGradient manipulation functions
An abstract type representing a gradient
createLinear ~pos1 ~pos2 creates a new linear gradient parallel to the line (pos1, pos2) in window coordinates
createRadial ~center1 ~rad1 ~center2 ~rad2 creates a new radial gradient between the disks with centers center1 and center2 and radi rad1 and rad2 in window coordinates
createConic ~center ~angle creates a new conic gradient with center center and initial angle angle