Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
V1.ColorSourceColor description and manipulation functions
Abstract type for colors
of_rgb r g b creates a color from its r, g and b components. Those components are automatically clipped to the 0-255 range.
to_rgb c converts a color to its r, g and b components, ignoring the alpha component
of_argb a r g b creates a color from it a, r, g and b components. Those components are automatically clipped to the 0-255 range.
to_argb c converts a color to its a, r, g and b components
of_int i creates a color from its 24-bit integer representation i ; this representation does not include the alpha component. This integer is clipped to 24-bit beforehand.
to_int c converts a color c to its 24-bit integer representation ; this representation does not include the alpha component
of_string s returns the color associated with string s. s can be either a color name (as defined by define_color), or an hexadecimal representation of the form #AARRGGBB. If the color is unknown or unparsable, this returns transparent_black.